pub enum Interval {
Month(i32),
Microsecond(i64),
}Expand description
Represents a time interval, which can be either in months or microseconds.
The Interval type is divided into two variants: Interval::Month and Interval::Microsecond.
This distinction is made because the conversion between months and days is not consistent.
While a year can be clearly calculated as 12 months in the solar calendar,
a month can vary in the number of days (28, 30, or 31 days).
To ensure precise calculations and comparisons, intervals are represented in the smallest
unambiguous units: Month for month-based intervals and Microsecond for microsecond-based intervals.
Comparisons are only allowed within the same unit type to avoid ambiguity.
For more details on how comparisons are implemented, refer to the Interval::partial_cmp trait.
Variants
Implementations
Sourceimpl Interval
impl Interval
pub fn unary_minus(&self) -> Interval
pub fn add(&self, other: &Interval) -> Result<Interval, Error>
pub fn subtract(&self, other: &Interval) -> Result<Interval, Error>
pub fn add_date(&self, date: &NaiveDate) -> Result<NaiveDateTime, Error>
pub fn subtract_from_date( &self, date: &NaiveDate, ) -> Result<NaiveDateTime, Error>
pub fn add_timestamp( &self, timestamp: &NaiveDateTime, ) -> Result<NaiveDateTime, Error>
pub fn subtract_from_timestamp( &self, timestamp: &NaiveDateTime, ) -> Result<NaiveDateTime, Error>
pub fn add_time(&self, time: &NaiveTime) -> Result<NaiveTime, Error>
pub fn subtract_from_time(&self, time: &NaiveTime) -> Result<NaiveTime, Error>
pub fn years(years: i32) -> Interval
pub fn months(months: i32) -> Interval
pub fn extract(&self, field: &DateTimeField) -> Result<Value, Error>
pub fn days(days: i32) -> Interval
pub fn hours(hours: i32) -> Interval
pub fn minutes(minutes: i32) -> Interval
pub fn seconds(seconds: i64) -> Interval
pub fn milliseconds(milliseconds: i64) -> Interval
pub fn microseconds(microseconds: i64) -> Interval
pub fn try_from_str( value: &str, leading_field: Option<DateTimeField>, last_field: Option<DateTimeField>, ) -> Result<Interval, Error>